@@ -25,8 +25,13 @@ from astromodels.utils.configuration import get_user_data_path
 _TINY_ = 1e-50
 
 
-__all__ = ["IncompleteGrid", "ValuesNotInGrid",
-           "MissingDataFile", "TemplateModelFactory", "TemplateModel"]
+__all__ = [
+    "IncompleteGrid",
+    "ValuesNotInGrid",
+    "MissingDataFile",
+    "TemplateModelFactory",
+    "TemplateModel",
+]
 
 
 class IncompleteGrid(RuntimeError):
@@ -56,7 +61,6 @@ try:
     from interpolation.splines import eval_linear
 
     class GridInterpolate(object):
-
         def __init__(self, grid, values):
             self._grid = grid
             self._values = np.ascontiguousarray(values)
@@ -66,7 +70,6 @@ try:
             return eval_linear(self._grid, self._values, v)
 
     class UnivariateSpline(object):
-
         def __init__(self, x, y):
 
             self._x = x
@@ -84,9 +87,15 @@ except:
 
 
 class TemplateModelFactory(object):
-
-    def __init__(self, name, description, energies, names_of_parameters,
-                 interpolation_degree=1, spline_smoothing_factor=0):
+    def __init__(
+        self,
+        name,
+        description,
+        energies,
+        names_of_parameters,
+        interpolation_degree=1,
+        spline_smoothing_factor=0,
+    ):
 
         # Store model name
 
@@ -96,8 +105,10 @@ class TemplateModelFactory(object):
 
         if re.match("[a-zA-Z_][a-zA-Z0-9_]*", name) is None:
 
-            raise RuntimeError("The provided name '%s' is not a valid name. You cannot use spaces, "
-                               "or special characters")
+            raise RuntimeError(
+                "The provided name '%s' is not a valid name. You cannot use spaces, "
+                "or special characters"
+            )
 
         self._name = name
 
@@ -108,7 +119,8 @@ class TemplateModelFactory(object):
         if not isinstance(energies, u.Quantity):
 
             warnings.warn(
-                "Energy unit is not a Quantity instance, so units has not been provided. Using keV.")
+                "Energy unit is not a Quantity instance, so units has not been provided. Using keV."
+            )
 
             energies = energies * u.keV
 
@@ -135,16 +147,21 @@ class TemplateModelFactory(object):
 
     def define_parameter_grid(self, parameter_name, grid):
 
-        assert parameter_name in self._parameters_grids, "Parameter %s is not part of this model" % parameter_name
+        assert parameter_name in self._parameters_grids, (
+            "Parameter %s is not part of this model" % parameter_name
+        )
 
         grid_ = np.array(grid)
 
-        assert grid_.shape[0] > 1, "A grid for a parameter must contain at least two elements"
+        assert (
+            grid_.shape[0] > 1
+        ), "A grid for a parameter must contain at least two elements"
 
         # Assert that elements are unique
 
-        assert np.all(np.unique(
-            grid_) == grid_), "Non-unique elements in grid for parameter %s" % parameter_name
+        assert np.all(np.unique(grid_) == grid_), (
+            "Non-unique elements in grid for parameter %s" % parameter_name
+        )
 
         self._parameters_grids[parameter_name] = grid_
 
@@ -156,8 +173,10 @@ class TemplateModelFactory(object):
 
             if grid is None:
 
-                raise IncompleteGrid("You need to define a grid for all parameters, by using the "
-                                     "define_parameter_grid method.")
+                raise IncompleteGrid(
+                    "You need to define a grid for all parameters, by using the "
+                    "define_parameter_grid method."
+                )
 
         if self._data_frame is None:
 
@@ -165,13 +184,16 @@ class TemplateModelFactory(object):
 
             # Create the multi-index
 
-            self._multi_index = pd.MultiIndex.from_product(list(self._parameters_grids.values()),
-                                                           names=list(self._parameters_grids.keys()))
+            self._multi_index = pd.MultiIndex.from_product(
+                list(self._parameters_grids.values()),
+                names=list(self._parameters_grids.keys()),
+            )
 
             # Pre-fill the data matrix with nans, so we will know if some elements have not been filled
 
             self._data_frame = pd.DataFrame(
-                index=self._multi_index, columns=self._energies)
+                index=self._multi_index, columns=self._energies
+            )
 
         # Make sure we have all parameters and order the values in the same way as the dictionary
         parameters_values = np.zeros(len(self._parameters_grids)) * np.nan
@@ -186,40 +208,49 @@ class TemplateModelFactory(object):
 
         # If the user did not specify one of the parameters, then the parameters_values array will contain nan
 
-        assert np.all(np.isfinite(parameters_values)
-                      ), "You didn't specify all parameters' values."
+        assert np.all(
+            np.isfinite(parameters_values)
+        ), "You didn't specify all parameters' values."
 
         # Make sure we are dealing with pure numpy arrays (list and astropy.Quantity instances will be transformed)
         # First we transform the input into a u.Quantity (if it's not already)
 
         if not isinstance(differential_fluxes, u.Quantity):
 
-            differential_fluxes = np.array(
-                differential_fluxes) * 1 / (u.keV * u.s * u.cm ** 2)  # type: u.Quantity
+            differential_fluxes = (
+                np.array(differential_fluxes) * 1 / (u.keV * u.s * u.cm ** 2)
+            )  # type: u.Quantity
 
         # Then we transform it in the right units and we cast it back to a pure np.array
 
-        differential_fluxes = np.array(differential_fluxes.to(
-            old_div(1, (u.keV * u.s * u.cm ** 2))).value)
+        differential_fluxes = np.array(
+            differential_fluxes.to(old_div(1, (u.keV * u.s * u.cm ** 2))).value
+        )
 
         # Now let's check for valid inputs
 
-        assert self._energies.shape[0] == differential_fluxes.shape[0], "Differential fluxes and energies must have " \
-                                                                        "the same number of elements"
+        assert self._energies.shape[0] == differential_fluxes.shape[0], (
+            "Differential fluxes and energies must have " "the same number of elements"
+        )
 
         # Check that the provided value does not contains nan, inf nor zero (as the interpolation happens in the
         # log space)
-        assert np.all(np.isfinite(differential_fluxes)
-                      ), "You have invalid values in the differential flux (nan or inf)"
-        assert np.all(differential_fluxes >= 0), "You have negative values in the differential flux (which is of " \
-                                                 "course impossible)"
+        assert np.all(
+            np.isfinite(differential_fluxes)
+        ), "You have invalid values in the differential flux (nan or inf)"
+        assert np.all(differential_fluxes >= 0), (
+            "You have negative values in the differential flux (which is of "
+            "course impossible)"
+        )
 
         if not np.all(differential_fluxes > 0):
 
-            warnings.warn("You have zeros in the differential flux. Since the interpolation happens in the log space, "
-                          "this cannot be accepted. We will substitute zeros with %g" % _TINY_)
+            warnings.warn(
+                "You have zeros in the differential flux. Since the interpolation happens in the log space, "
+                "this cannot be accepted. We will substitute zeros with %g" % _TINY_
+            )
 
-            idx = (differential_fluxes == 0)  # type: np.ndarray
+            idx = differential_fluxes == 0  # type: np.ndarray
             differential_fluxes[idx] = _TINY_
 
         # Now set the corresponding values in the data frame
@@ -228,13 +259,22 @@ class TemplateModelFactory(object):
 
         try:
 
-            self._data_frame.loc[tuple(parameters_values)] = pd.to_numeric(
-                differential_fluxes)
+            tmp = pd.to_numeric(differential_fluxes)
+
+            if len(parameters_values) == 1:
+
+                self._data_frame.loc[parameters_values.tolist()] = np.atleast_2d(tmp)
+
+            else:
+
+                self._data_frame.loc[tuple(parameters_values)] = tmp
 
         except KeyError:
 
             raise ValuesNotInGrid(
-                "The provided parameter values (%s) are not in the defined grid" % parameters_values)
+                "The provided parameter values (%s) are not in the defined grid"
+                % parameters_values
+            )
 
     @staticmethod
     def _clean_cols_for_hdf(data):
@@ -251,9 +291,11 @@ class TemplateModelFactory(object):
 
         # First make sure that the whole data matrix has been filled
 
-        assert not self._data_frame.isnull().values.any(), "You have NaNs in the data matrix. Usually this means " \
-                                                           "that you didn't fill it up completely, or that some of " \
-                                                           "your data contains nans. Cannot save the file."
+        assert not self._data_frame.isnull().values.any(), (
+            "You have NaNs in the data matrix. Usually this means "
+            "that you didn't fill it up completely, or that some of "
+            "your data contains nans. Cannot save the file."
+        )
 
         # Get the data directory
 
@@ -262,7 +304,8 @@ class TemplateModelFactory(object):
         # Sanitize the data file
 
         filename_sanitized = os.path.abspath(
-            os.path.join(data_dir_path, '%s.h5' % self._name))
+            os.path.join(data_dir_path, "%s.h5" % self._name)
+        )
 
         # Check that it does not exists
         if os.path.exists(filename_sanitized):
@@ -275,13 +318,17 @@ class TemplateModelFactory(object):
 
                 except:
 
-                    raise IOError("The file %s already exists and cannot be removed (maybe you do not have "
-                                  "permissions to do so?). " % filename_sanitized)
+                    raise IOError(
+                        "The file %s already exists and cannot be removed (maybe you do not have "
+                        "permissions to do so?). " % filename_sanitized
+                    )
 
             else:
 
-                raise IOError("The file %s already exists! You cannot call two different "
-                              "template models with the same name" % filename_sanitized)
+                raise IOError(
+                    "The file %s already exists! You cannot call two different "
+                    "template models with the same name" % filename_sanitized
+                )
 
         # Open the HDF5 file and write objects
 
@@ -290,21 +337,23 @@ class TemplateModelFactory(object):
             # The _clean_cols_for_hdf is needed because for some reasons the format of some columns
             # is not accepted by .to_hdf otherwise
 
-            self._clean_cols_for_hdf(
-                self._data_frame).to_hdf(store, 'data_frame')
+            self._clean_cols_for_hdf(self._data_frame).to_hdf(store, "data_frame")
 
-            store.get_storer('data_frame').attrs.metadata = {'description': self._description,
-                                                             'name': self._name,
-                                                             'interpolation_degree': int(self._interpolation_degree),
-                                                             'spline_smoothing_factor': self._spline_smoothing_factor
-                                                             }
+            store.get_storer("data_frame").attrs.metadata = {
+                "description": self._description,
+                "name": self._name,
+                "interpolation_degree": int(self._interpolation_degree),
+                "spline_smoothing_factor": self._spline_smoothing_factor,
+            }
 
             for i, parameter_name in enumerate(self._parameters_grids.keys()):
 
-                store['p_%i_%s' % (i, parameter_name)] = pd.Series(
-                    self._parameters_grids[parameter_name])
+                store["p_%i_%s" % (i, parameter_name)] = pd.Series(
+                    self._parameters_grids[parameter_name]
+                )
+
+            store["energies"] = pd.Series(self._energies)
 
-            store['energies'] = pd.Series(self._energies)
 
 # This adds a method to a class at runtime
 
@@ -329,8 +378,7 @@ class RectBivariateSplineWrapper(object):
 
         # We can use interp2, which features spline interpolation instead of linear interpolation
 
-        self._interpolator = scipy.interpolate.RectBivariateSpline(
-            *args, **kwargs)
+        self._interpolator = scipy.interpolate.RectBivariateSpline(*args, **kwargs)
 
     def __call__(self, x):
 
@@ -375,12 +423,15 @@ class TemplateModel(with_metaclass(FunctionMeta, Function1D)):
         # Sanitize the data file
 
         filename_sanitized = os.path.abspath(
-            os.path.join(data_dir_path, '%s.h5' % model_name))
+            os.path.join(data_dir_path, "%s.h5" % model_name)
+        )
 
         if not os.path.exists(filename_sanitized):
 
-            raise MissingDataFile("The data file %s does not exists. Did you use the "
-                                  "TemplateFactory?" % (filename_sanitized))
+            raise MissingDataFile(
+                "The data file %s does not exists. Did you use the "
+                "TemplateFactory?" % (filename_sanitized)
+            )
 
         # Open the template definition and read from it
 
@@ -388,7 +439,7 @@ class TemplateModel(with_metaclass(FunctionMeta, Function1D)):
 
         with HDFStore(filename_sanitized) as store:
 
-            self._data_frame = store['data_frame']
+            self._data_frame = store["data_frame"]
 
             self._parameters_grids = collections.OrderedDict()
 
@@ -396,7 +447,7 @@ class TemplateModel(with_metaclass(FunctionMeta, Function1D)):
 
             for key in list(store.keys()):
 
-                match = re.search('p_([0-9]+)_(.+)', key)
+                match = re.search("p_([0-9]+)_(.+)", key)
 
                 if match is None:
 
@@ -409,57 +460,62 @@ class TemplateModel(with_metaclass(FunctionMeta, Function1D)):
                     this_parameter_number = int(tokens[0])
                     this_parameter_name = str(tokens[1])
 
-                    assert this_parameter_number == processed_parameters, "Parameters out of order!"
+                    assert (
+                        this_parameter_number == processed_parameters
+                    ), "Parameters out of order!"
 
                     self._parameters_grids[this_parameter_name] = store[key]
 
                     processed_parameters += 1
 
-            self._energies = np.array(store['energies'])
+            self._energies = np.array(store["energies"])
 
             # Now get the metadata
 
-            metadata = store.get_storer('data_frame').attrs.metadata
+            metadata = store.get_storer("data_frame").attrs.metadata
 
-            description = metadata['description']
-            name = metadata['name']
+            description = metadata["description"]
+            name = metadata["name"]
 
-            self._interpolation_degree = metadata['interpolation_degree']
+            self._interpolation_degree = metadata["interpolation_degree"]
 
-            self._spline_smoothing_factor = metadata['spline_smoothing_factor']
+            self._spline_smoothing_factor = metadata["spline_smoothing_factor"]
 
         # Make the dictionary of parameters
 
         function_definition = collections.OrderedDict()
 
-        function_definition['description'] = description
+        function_definition["description"] = description
 
-        function_definition['latex'] = 'n.a.'
+        function_definition["latex"] = "n.a."
 
         # Now build the parameters according to the content of the parameter grid
 
         parameters = collections.OrderedDict()
 
-        parameters['K'] = Parameter('K', 1.0)
-        parameters['scale'] = Parameter('scale', 1.0)
+        parameters["K"] = Parameter("K", 1.0)
+        parameters["scale"] = Parameter("scale", 1.0)
 
         for parameter_name in list(self._parameters_grids.keys()):
 
             grid = self._parameters_grids[parameter_name]
 
-            parameters[parameter_name] = Parameter(parameter_name, grid.median(),
-                                                   min_value=grid.min(),
-                                                   max_value=grid.max())
+            parameters[parameter_name] = Parameter(
+                parameter_name,
+                grid.median(),
+                min_value=grid.min(),
+                max_value=grid.max(),
+            )
 
         if other_name is None:
 
-            super(TemplateModel, self).__init__(
-                name, function_definition, parameters)
+            super(TemplateModel, self).__init__(name, function_definition, parameters)
 
         else:
 
             super(TemplateModel, self).__init__(
-                other_name, function_definition, parameters)
+                other_name, function_definition, parameters
+            )
 
         # Finally prepare the interpolators
 
@@ -468,8 +524,7 @@ class TemplateModel(with_metaclass(FunctionMeta, Function1D)):
     def _prepare_interpolators(self, log_interp):
 
         # Figure out the shape of the data matrices
-        data_shape = [x.shape[0]
-                      for x in list(self._parameters_grids.values())]
+        data_shape = [x.shape[0] for x in list(self._parameters_grids.values())]
 
         self._interpolators = []
 
@@ -482,7 +537,9 @@ class TemplateModel(with_metaclass(FunctionMeta, Function1D)):
             if log_interp:
 
                 this_data = np.array(
-                    np.log10(self._data_frame[energy].values).reshape(*data_shape), dtype=float)
+                    np.log10(self._data_frame[energy].values).reshape(*data_shape),
+                    dtype=float,
+                )
 
                 self._is_log10 = True
 
@@ -490,7 +547,8 @@ class TemplateModel(with_metaclass(FunctionMeta, Function1D)):
 
                 # work in linear space
                 this_data = np.array(
-                    self._data_frame[energy].values.reshape(*data_shape), dtype=float)
+                    self._data_frame[energy].values.reshape(*data_shape), dtype=float
+                )
 
                 self._is_log10 = False
 
@@ -501,31 +559,51 @@ class TemplateModel(with_metaclass(FunctionMeta, Function1D)):
                 # Make sure that the requested polynomial degree is less than the number of data sets in
                 # both directions
 
-                msg = "You cannot use an interpolation degree of %s if you don't provide at least %s points " \
-                      "in the %s direction. Increase the number of templates or decrease the interpolation " \
-                      "degree."
+                msg = (
+                    "You cannot use an interpolation degree of %s if you don't provide at least %s points "
+                    "in the %s direction. Increase the number of templates or decrease the interpolation "
+                    "degree."
+                )
 
                 if len(x) <= self._interpolation_degree:
 
                     raise RuntimeError(
-                        msg % (self._interpolation_degree, self._interpolation_degree+1, 'x'))
+                        msg
+                        % (
+                            self._interpolation_degree,
+                            self._interpolation_degree + 1,
+                            "x",
+                        )
+                    )
 
                 if len(y) <= self._interpolation_degree:
 
                     raise RuntimeError(
-                        msg % (self._interpolation_degree, self._interpolation_degree + 1, 'y'))
+                        msg
+                        % (
+                            self._interpolation_degree,
+                            self._interpolation_degree + 1,
+                            "y",
+                        )
+                    )
 
-                this_interpolator = RectBivariateSplineWrapper(x, y, this_data,
-                                                               kx=self._interpolation_degree,
-                                                               ky=self._interpolation_degree,
-                                                               s=self._spline_smoothing_factor)
+                this_interpolator = RectBivariateSplineWrapper(
+                    x,
+                    y,
+                    this_data,
+                    kx=self._interpolation_degree,
+                    ky=self._interpolation_degree,
+                    s=self._spline_smoothing_factor,
+                )
 
             else:
 
                 # In more than 2d we can only use linear interpolation
 
-                this_interpolator = GridInterpolate(tuple([np.array(x) for x in list(self._parameters_grids.values())]),
-                                                    this_data)
+                this_interpolator = GridInterpolate(
+                    tuple([np.array(x) for x in list(self._parameters_grids.values())]),
+                    this_data,
+                )
 
             self._interpolators.append(this_interpolator)
 
@@ -550,8 +628,9 @@ class TemplateModel(with_metaclass(FunctionMeta, Function1D)):
             # a dimensionless quantity (actually we take the .value property) because otherwise
             # the logarithm below will fail.
 
-            energies = np.array(energies.to('keV').value,
-                                ndmin=1, copy=False, dtype=float)
+            energies = np.array(
+                energies.to("keV").value, ndmin=1, copy=False, dtype=float
+            )
 
             # Same for the scale
 
@@ -571,8 +650,12 @@ class TemplateModel(with_metaclass(FunctionMeta, Function1D)):
         # (these are the logarithm of the values)
         # note that if these are not logged, then the name is superflous
 
-        log_interpolations = np.array([self._interpolators[i](np.atleast_1d(
-            parameters_values)) for i in range(self._energies.shape[0])])
+        log_interpolations = np.array(
+            [
+                self._interpolators[i](np.atleast_1d(parameters_values))
+                for i in range(self._energies.shape[0])
+            ]
+        )
 
         # Now interpolate the interpolations to get the flux at the requested energies
 
@@ -580,8 +663,7 @@ class TemplateModel(with_metaclass(FunctionMeta, Function1D)):
 
         if self._is_log10:
 
-            interpolator = UnivariateSpline(
-                np.log10(e_tilde), log_interpolations)
+            interpolator = UnivariateSpline(np.log10(e_tilde), log_interpolations)
 
             values = np.power(10, interpolator(log_energies))
 
@@ -618,7 +700,11 @@ class TemplateModel(with_metaclass(FunctionMeta, Function1D)):
 
 class XSPECTableModel(object):
     def __init__(
-            self, xspec_table_model_file, interpolation_degree=1, spline_smoothing_factor=0, log_centers=True
+        self,
+        xspec_table_model_file,
+        interpolation_degree=1,
+        spline_smoothing_factor=0,
+        log_centers=True,
     ):
         """
         Convert an XSPEC table model to an astromodels TemplateModel.
@@ -665,7 +751,7 @@ class XSPECTableModel(object):
 
             else:
 
-                self._energy = (ene_hi + ene_lo)/2.
+                self._energy = (ene_hi + ene_lo) / 2.0
 
             params = f["PARAMETERS"]
 
